package com.tanpu.feo.feojob.jobs;

import com.tanpu.feo.feojob.dao.admin.entity.OrgConfig;
import com.tanpu.feo.feojob.enums.OrgConfigKeyEnum;
import com.tanpu.feo.feojob.service.CurriculumResService;
import com.tanpu.feo.feojob.service.OrgConfigService;
import lombok.extern.slf4j.Slf4j;
import org.checkerframework.checker.units.qual.A;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

@Component
@Slf4j
public class SyncOrgShortVideoJob {

    @Autowired
    private OrgConfigService orgConfigService;

    @Autowired
    private CurriculumResService resService;

    @Scheduled(cron = "0 0 0 * * ? ")
    public void execute() {
        List<OrgConfig> configs = orgConfigService.selectByKey(OrgConfigKeyEnum.Sync_Select_Short_Video.key);

        Map<String, String> autoOnMap = orgConfigService.selectByKey(OrgConfigKeyEnum.Sync_Video_Auto_On.key)
                .stream().collect(Collectors.toMap(OrgConfig::getOrgId, OrgConfig::getCfgValue));
        for (OrgConfig config : configs) {
            if (!Boolean.parseBoolean(config.getCfgValue())) {
                continue;
            }
            // 开始同步
            String orgId = config.getOrgId();
            try {
                Boolean autoOn = autoOnMap.containsKey(orgId) ? Boolean.parseBoolean(autoOnMap.get(orgId)) : false;
                resService.migrateShortVideo(config.getOrgId(), autoOn);
            } catch (Exception e) {
                log.error("error in sync short video for org {}", orgId);
            }
        }
    }
}
